DirBuilder

Struct DirBuilder 

1.6.0 · Source
pub struct DirBuilder { /* private fields */ }
A builder used to create directories in various manners.

This builder also supports platform-specific options.

Implementations

Source

impl DirBuilder

1.6.0 · Source

pub fn new() -> DirBuilder

Creates a new set of options with default mode/security settings for all platforms and also non-recursive.

Examples
use std::fs::DirBuilder;

let builder = DirBuilder::new();
1.6.0 · Source

pub fn recursive(&mut self, recursive: bool) -> &mut DirBuilder

Indicates that directories should be created recursively, creating all parent directories. Parents that do not exist are created with the same security and permissions settings.

This option defaults to false.

Examples
use std::fs::DirBuilder;

let mut builder = DirBuilder::new();
builder.recursive(true);
1.6.0 · Source

pub fn create<P>(&self, path: P) -> Result<(), Error>
where P: AsRef<Path>,

Creates the specified directory with the options configured in this builder.

It is considered an error if the directory already exists unless recursive mode is enabled.

Examples
use std::fs::{self, DirBuilder};

let path = "/tmp/foo/bar/baz";
DirBuilder::new()
    .recursive(true)
    .create(path).unwrap();

assert!(fs::metadata(path).unwrap().is_dir());