Module version_checker

Module version_checker 

Functions

check_outdated_binary
Checks if there is a newer compiled ggen binary in the target directory compared to the running one, and prints a warning if so.