pub fn enable(
surface: String,
projection: Option<String>,
runtime: Option<String>,
) -> Result<Value>Expand description
Enable a capability: expand it to atomic packs and record them in the project lockfile, returning the expansion as JSON.